==> nextcloud-18.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/bg.js <==
OC.L10N.register(
    "theming",
    {
    "Saved" : "Запазено",
    "Admin" : "Админ",
    "a safe home for all your data" : "безопасен дом за всички ваши данни",
    "The given name is too long" : "Името е прекалено дълго",
    "The given web address is too long" : "Въведеният уеб адрес е твърде дълъг",
    "The given slogan is too long" : "Избраният лозунг е твърде дълъг",
    "The given color is invalid" : "Избраният цвят е невалиден",
    "The file was uploaded" : "Файлът е качен",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Размерът на файла надвишава максималния размер определен от MAX_FILE_SIZE в HTML формата.",
    "The file was only partially uploaded" : "Файлът е качен частично",
    "No file was uploaded" : "Нито един файл не е качен",
    "Missing a temporary folder" : "Липсва временна папка",
    "No file uploaded" : "Няма качен файл",
    "Unsupported image type" : "Неподдържан тип изображение",
    "Theming" : "Теми",
    "Open documentation" : "Отвори документацията",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Чрез темите можете бързо и лесно за персонализирате вида на Nextcloud. Промените ще бъдат видими за всички потребители.",
    "Name" : "Име",
    "Web link" : "URL",
    "Slogan" : "Лозунг",
    "Color" : "Цвят",
    "Logo" : "Лого",
    "Upload new logo" : "Качване на ново лого",
    "Login image" : "Изображение при вписване",
    "Upload new login background" : "Качване на нов фон за входа",
    "Advanced options" : "Допълнителни опции"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/bg.js <==
OC.L10N.register(
    "theming",
    {
    "Saved" : "Запазено",
    "Admin" : "Админ",
    "a safe home for all your data" : "безопасен дом за всички ваши данни",
    "Name cannot be empty" : "Името не може да бъде празно",
    "The given name is too long" : "Името е прекалено дълго",
    "The given web address is too long" : "Въведеният уеб адрес е твърде дълъг",
    "The given slogan is too long" : "Избраният лозунг е твърде дълъг",
    "The given color is invalid" : "Избраният цвят е невалиден",
    "The file was uploaded" : "Файлът е качен",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Размерът на файла надвишава максималния размер определен от MAX_FILE_SIZE в HTML формата.",
    "The file was only partially uploaded" : "Файлът е качен частично",
    "No file was uploaded" : "Нито един файл не е качен",
    "Missing a temporary folder" : "Липсва временна папка",
    "No file uploaded" : "Няма качен файл",
    "Theming" : "Теми",
    "Open documentation" : "Отвори документацията",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Чрез темите можете бързо и лесно за персонализирате вида на Nextcloud. Промените ще бъдат видими за всички потребители.",
    "Name" : "Име",
    "Reset to default" : "Настройки по подразбиране",
    "Web link" : "URL",
    "Slogan" : "Лозунг",
    "Color" : "Цвят",
    "Logo" : "Лого",
    "Upload new logo" : "Качване на ново лого",
    "Login image" : "Изображение при вписване",
    "Upload new login background" : "Качване на нов фон за входа",
    "Remove background image" : "Премахни фоновото изображение",
    "Advanced options" : "Допълнителни опции",
    "Header logo" : "Главно лого",
    "Favicon" : "Фавиконка"
},
"nplurals=2; plural=(n != 1);");
